# Tools
![License MIT](https://img.shields.io/badge/license-MIT-blue.svg)

[个人博客](https://jxlss.cn)

#### Project management of Python daily tools
```shell 
    pip install Eric-Tools
```

```
encryption_classmethod.py  Python HMAC+MD5加密签名算法

exception_class.py  异常类

resize_image.py 图片压缩

ip.py   ip地址定位API

logger.py  日志模块类和高级日志装饰器

remove.py 删除文件

send_email.py  发送邮件

sftp.py   ssh远程下载文件

pgsql.py  对postgresql 增删改查操作
```
